package org.joget.sample;

import java.io.IOException;
import java.util.Map;
import java.util.Set;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.joget.apps.app.service.AppUtil;
import org.joget.plugin.base.DefaultApplicationPlugin;
import org.joget.plugin.base.PluginWebSupport;
import org.joget.workflow.model.service.WorkflowUserManager;
import org.joget.workflow.util.WorkflowUtil;

public class DependencyPluginOptions extends DefaultApplicationPlugin implements PluginWebSupport {
    public String getName() {
        return "Dependency Plugin Options Sample Tool";
    }
    
    public String getLabel() {
        return getName();
    }

    public String getClassName() {
        return getClass().getName();
    }

    public String getPropertyOptions() {
        return AppUtil.readPluginResource(getClass().getName(), "/properties/app/pluginOptions.json", null, true, null);
    }

    public String getDescription() {
        return "To demonstrate how to make the plugin options load dynamically and dependent on other field.";
    }

    public String getVersion() {
        return "1.0.0";
    }
    
    public Object execute(Map properties) {
        //To retrieve the values of dependecy options object
        Object optionObj = properties.get("option");
        if (optionObj instanceof Map) {
            Map temp = (Map) optionObj;
            
            // to get the value of option
            String option = temp.get("className").toString();
            System.out.println("Option : " + option);
            
            // to get the value of dependecy fields
            Map optionProp = (Map) temp.get("properties");
            for (String key : (Set<String>) optionProp.keySet()) {
                System.out.println(key + " : " + optionProp.get(key));
            }
        }
        
        return null;
    }

    public void webService(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        boolean isAdmin = WorkflowUtil.isCurrentUserInRole(WorkflowUserManager.ROLE_ADMIN);
        if (!isAdmin) {
            response.sendError(HttpServletResponse.SC_UNAUTHORIZED);
            return;
        }
        
        String action = request.getParameter("action");
        if ("getJson".equals(action)) {
            String value = request.getParameter("value");
            
            String output = "";
            if (value != null && !value.isEmpty()) {
                output = AppUtil.readPluginResource(getClass().getName(), "/properties/app/pluginOptions_"+value+".json", null, true, null);
            }
            response.getWriter().write(output);
        } else {
            response.setStatus(HttpServletResponse.SC_NO_CONTENT);
        }
    }
}
